@@ -107,16 +107,20 @@ Ext.define('MP.data.MetaData', {
                 },
 
                 failure: function (r) {
-                    var res = r.responseText && Ext.decode(r.responseText);
-                    if(res) {
-                        Ext.MessageBox.alert(
-                            // TRANSLATORS: {0} is the error code, {1} the error message
-                            Ext.String.format(_('Communication error ({0} {1})'),
-                                              r.status, r.statusText),
-                            res.message);
+                    if(r.status >= 400) {
+                        Ext.MessageBox.alert(r.statusText, r.responseText);
                     } else {
-                        Ext.MessageBox.alert(_('Communication error'),
-                                             r.statusText);
+                        var res = r.responseText && Ext.decode(r.responseText);
+                        if(res) {
+                            Ext.MessageBox.alert(
+                                // TRANSLATORS: {0} is the error code, {1} the error message
+                                Ext.String.format(_('Communication error ({0} {1})'),
+                                                  r.status, r.statusText),
+                                res.message);
+                        } else {
+                            Ext.MessageBox.alert(_('Communication error'),
+                                                 r.statusText);
+                        }
                     }
                     if(error_callback) error_callback(r);
                 }
